@@ -5,6 +5,7 @@
 @author: Nick Leppänen Larsson <frals@frals.se>
 @license: GNU GPL
 """
+import os
 
 try:
 	import gnome.gconf as gconf
@@ -25,6 +26,8 @@ class fMMS_config:
 			self.set_pushdir("/home/user/.fmms/push/")
 		if self.get_mmsdir() == None:
 			self.set_mmsdir("/home/user/.fmms/mms/")
+		if self.get_outdir() == None:
+			self.set_outdir("/home/user/.fmms/sent/")
 		if self.get_imgdir() == None:
 			self.set_imgdir("/home/user/.fmms/temp/")
 		if self.get_mmsc() == None:
@@ -37,6 +40,18 @@ class fMMS_config:
 			self.set_version("Unknown")
 		if self.get_db_path() == None:
 			self.set_db_path("/home/user/.fmms/mms.db")
+		# Create dirs, for good measures
+		if not os.path.isdir(self.get_pushdir()):
+			os.makedirs(self.get_pushdir())
+		
+		if not os.path.isdir(self.get_mmsdir()):
+			os.makedirs(self.get_mmsdir())
+
+		if not os.path.isdir(self.get_outdir()):
+			os.makedirs(self.get_outdir())
+			
+		if not os.path.isdir(self.get_imgdir()):
+			os.makedirs(self.get_imgdir())
 		
 	def read_config(self):
 		pass
@@ -86,6 +101,12 @@ class fMMS_config:
 
 	def get_mmsdir(self):
 		return self.client.get_string(self._fmmsdir + "mmsdir")
+	
+	def set_outdir(self, path):
+		self.client.set_string(self._fmmsdir + "outdir", path)
+	
+	def get_outdir(self):
+		return self.client.get_string(self._fmmsdir + "outdir")
 		
 	def set_imgdir(self, path):
 		self.client.set_string(self._fmmsdir + "imgdir", path)
@@ -166,10 +187,3 @@ class fMMS_config:
 		
 if __name__ == '__main__':
 	config = fMMS_config()
-	#config.get_apnid_from_name("Tele2 MMS")
-	#config.set_apn("bogus")
-	#config.set_pushdir("/home/user/.fmms/push/")
-	#config.set_mmsdir("/home/user/.fmms/mms/")
-	#config.set_mmsc("http://bogus")
-	#print config.get_apn()
-	#print config.get_apn_nicename()
\ No newline at end of file
